==> baseui-5.4.0.tgz: package/toast/__tests__/toaster.test.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _reactDom = _interopRequireDefault(require("react-dom"));

var _enzyme = require("enzyme");

var _index = require("../index.js");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

// Mock React 16 portals
var originalCreatePortal = _reactDom.default.createPortal;
jest.useFakeTimers();
describe('toaster', function () {
  var wrapper;
  beforeAll(function () {
    // $FlowFixMe
    _reactDom.default.createPortal = jest.fn(function (children) {
      return _react.default.createElement("div", {
        "is-portal": "true",
        key: "portal"
      }, children);
    });
  });
  afterEach(function () {
    _reactDom.default.createPortal.mockClear();

    wrapper && wrapper.unmount();
  });
  afterAll(function () {
    // $FlowFixMe
    _reactDom.default.createPortal = originalCreatePortal;
  });
  test('ToasterContainer', function () {
    wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.ToasterContainer, null));
    var renderedToaster = wrapper.find(_index.ToasterContainer).first();
    expect(renderedToaster.instance().state.isMounted).toBe(true);
    expect(renderedToaster.instance().state.toasts.length).toEqual(0);
    expect(wrapper.find(_index.StyledRoot).first()).toExist();
  });
  describe('ToasterContainer props', function () {
    test.each(Object.keys(_index.PLACEMENT).map(function (pl) {
      return [pl];
    }))('%s placement is passed to the Toaster and StyledRoot component', function (placement) {
      var props = {
        placement: placement
      };
      wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.ToasterContainer, props));
      expect(wrapper.find(_index.ToasterContainer).first().props().placement).toEqual(placement);
      expect(wrapper.find(_index.StyledRoot).first().props().$placement).toEqual(placement);
    });
    test('portal is created when usePortal is set to true', function () {
      wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.ToasterContainer, null));
      expect(wrapper.find(_index.ToasterContainer).first().props().usePortal).toBe(true);
      expect(_reactDom.default.createPortal).toHaveBeenCalled();
    });
    test('portal is not created when usePortal is set to false', function () {
      wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.ToasterContainer, {
        usePortal: false
      }));
      expect(wrapper.find(_index.ToasterContainer).first().props().usePortal).toBe(false);
      expect(_reactDom.default.createPortal).not.toHaveBeenCalled();
    });
  });
  describe('toaster overrides', function () {
    test('Inner components override', function () {
      var overrides = {
        Root: jest.fn().mockImplementation(function (_ref) {
          var children = _ref.children;
          return _react.default.createElement("div", null, children);
        }),
        ToastBody: jest.fn().mockImplementation(function (_ref2) {
          var children = _ref2.children;
          return _react.default.createElement("div", null, children);
        }),
        ToastCloseIcon: jest.fn().mockImplementation(function (_ref3) {
          var children = _ref3.children;
          return _react.default.createElement("svg", null, children);
        })
      }; // $FlowFixMe

      wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.ToasterContainer, {
        overrides: overrides
      }));
      var renderedToaster = wrapper.find(_index.ToasterContainer).first();
      _index.toaster.getRef = jest.fn().mockReturnValue(renderedToaster.instance());

      _index.toaster.show('Toast message');

      wrapper.update();
      Object.keys(overrides).forEach(function (name) {
        expect(wrapper.find(overrides[name]).first()).toExist();
      });
    });
    test('Inner components props and styles overrides', function () {
      var overrides = {
        Root: {
          props: {
            'data-attr': 'root'
          },
          style: {
            borderColor: 'skyblue'
          }
        },
        ToastBody: {
          props: {
            'data-attr': 'body'
          },
          style: {
            backgroundColor: 'skyblue'
          }
        },
        ToastCloseIcon: {
          props: {
            'data-attr': 'closeIcon'
          },
          style: {
            color: 'blue'
          }
        }
      };
      var components = {
        Root: _index.StyledRoot,
        ToastBody: _index.StyledBody,
        ToastCloseIcon: _index.StyledCloseIcon
      };
      wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.ToasterContainer, {
        overrides: overrides
      }));
      var renderedToaster = wrapper.find(_index.ToasterContainer).first();
      _index.toaster.getRef = jest.fn().mockReturnValue(renderedToaster.instance());

      _index.toaster.show('Toast message');

      wrapper.update();
      Object.keys(overrides).forEach(function (name) {
        var passedProps = wrapper.find(components[name]).first().props();
        expect(passedProps['data-attr']).toEqual(overrides[name].props['data-attr']);
        expect(passedProps.$style).toEqual(overrides[name].style);
      });
    });
  });
  describe('toaster methods', function () {
    var renderedToaster;
    beforeEach(function () {
      wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.ToasterContainer, null));
      renderedToaster = wrapper.find(_index.ToasterContainer).first();
      _index.toaster.getRef = jest.fn().mockReturnValue(renderedToaster.instance());
    });
    test('toaster[show | update | clear]', function () {
      var toastCounter = 0;
      var toasterInstance = renderedToaster.instance(); // test toast is updated

      function getKey() {
        return "test-toast-".concat(toastCounter++);
      }

      var MockNode1 = jest.fn().mockImplementation(function () {
        return 'Toast 1';
      });
      var MockNode2 = jest.fn().mockImplementation(function () {
        return 'Toast 2';
      });
      var props1 = {
        key: getKey(),
        children: _react.default.createElement(MockNode1, null)
      };
      var props2 = {
        key: getKey(),
        children: _react.default.createElement(MockNode2, null)
      };
      var showSpy = jest.spyOn(toasterInstance, 'show'); // add the first Toast

      var toastKey1 = _index.toaster.show(props1.children, {
        key: props1.key
      });

      jest.runAllTimers();
      expect(showSpy).toHaveBeenCalledTimes(1);
      expect(showSpy).toHaveBeenCalledWith(props1);
      expect(toasterInstance.state.toasts.length).toEqual(1);
      expect(toasterInstance.state.toasts[0]).toMatchObject(props1); // verify that first Toast is rendered

      wrapper.update();
      expect(wrapper.find(_index.Toast).length).toEqual(1);
      expect(wrapper.find(_index.StyledBody).length).toEqual(1);
      expect(wrapper.find(MockNode1).length).toEqual(1); // add the second Toast

      _index.toaster.show(props2.children, {
        key: props2.key
      });

      jest.runAllTimers();
      expect(showSpy).toHaveBeenCalledTimes(2);
      expect(showSpy).toHaveBeenLastCalledWith(props2);
      expect(toasterInstance.state.toasts.length).toEqual(2);
      expect(toasterInstance.state.toasts[1]).toMatchObject(props2); // verify that second Toast is rendered

      wrapper.update();
      expect(wrapper.find(_index.Toast).length).toEqual(2);
      expect(wrapper.find(_index.StyledBody).length).toEqual(2);
      expect(wrapper.find(MockNode2).length).toEqual(1); // test toast is updated

      var updateSpy = jest.spyOn(toasterInstance, 'update');
      var MockNode3 = jest.fn().mockImplementation(function () {
        return 'Toast updated';
      });
      var updatedProps = {
        children: _react.default.createElement(MockNode3, null),
        kind: _index.KIND.positive
      };

      _index.toaster.update(toastKey1, updatedProps);

      jest.runAllTimers();
      expect(updateSpy).toHaveBeenCalled();
      expect(updateSpy).toHaveBeenCalledWith(toastKey1, updatedProps);
      expect(toasterInstance.state.toasts.length).toEqual(2);
      expect(toasterInstance.state.toasts[0]).toMatchObject(_objectSpread({}, props1, updatedProps));
      expect(toasterInstance.state.toasts[1]).toMatchObject(props2); // verify that updated children are rendered

      wrapper.update();
      expect(wrapper.find(_index.Toast).length).toEqual(2);
      expect(wrapper.find(_index.StyledBody).length).toEqual(2);
      expect(wrapper.find(MockNode1).length).toEqual(0);
      expect(wrapper.find(MockNode3).length).toEqual(1); // test toast is cleared

      var clearSpy = jest.spyOn(toasterInstance, 'clear');

      _index.toaster.clear(toastKey1);

      jest.runAllTimers();
      expect(clearSpy).toHaveBeenCalled();
      expect(clearSpy).toHaveBeenCalledWith(toastKey1);
      expect(toasterInstance.state.toasts.length).toEqual(1); // verify that dismissed toast is not rendered

      wrapper.update();
      expect(wrapper.find(_index.Toast).length).toEqual(1);
      expect(wrapper.find(_index.StyledBody).length).toEqual(1);
      expect(wrapper.find(MockNode3).length).toEqual(0);
      expect(wrapper.find(MockNode2).length).toEqual(1);
    });
    test('info, positive, warning, negative methods and clear all', function () {
      var toasterInstance = renderedToaster.instance();
      var counter = 0;
      ['info', 'positive', 'warning', 'negative'].forEach(function (method) {
        var children = "".concat(method, " toast");

        _index.toaster[method](children);

        counter++;
        var toastsLength = toasterInstance.state.toasts.length;
        expect(toastsLength).toEqual(counter);
        expect(toasterInstance.state.toasts[toastsLength - 1]).toMatchObject({
          key: "toast-".concat(counter - 1),
          children: children,
          kind: _index.KIND[method]
        });
      }); // verify all toasts rendered

      jest.runAllTimers();
      wrapper.update();
      expect(wrapper.find(_index.Toast).length).toEqual(4); // verify oldest toasts are rendered last in the tree

      expect(wrapper.find(_index.Toast).last().props()).toMatchObject({
        kind: _index.KIND.info
      }); // verify all toasts are cleared

      var clearSpy = jest.spyOn(toasterInstance, 'clear');

      _index.toaster.clear();

      jest.runAllTimers();
      expect(clearSpy).toHaveBeenCalled();
      expect(clearSpy).toHaveBeenCalledWith(undefined); // verify no toasts are rendered

      wrapper.update();
      expect(wrapper.find(_index.Toast).length).toEqual(0);
    });
    test('onClose toast handler is called', function () {
      var onClose = jest.fn();

      var toastKey = _index.toaster.show('Toast message', {
        onClose: onClose
      }); // verify the toast is rendered


      wrapper.update();
      expect(wrapper.find(_index.Toast).length).toEqual(1); // verify the toast is cleared

      _index.toaster.clear(toastKey);

      jest.runAllTimers(); // verify the onClose toast handler is called

      expect(onClose).toHaveBeenCalled(); // verify no toasts are rendered

      wrapper.update();
      expect(wrapper.find(_index.Toast).length).toEqual(0);
    });
    test('toast is cleared and onClose is called when it is dissmissed by a user', function () {
      var toasterInstance = renderedToaster.instance();
      var onClose = jest.fn();

      _index.toaster.show('Toast message', {
        onClose: onClose
      }); // verify the toast is rendered


      wrapper.update();
      expect(wrapper.find(_index.Toast).length).toEqual(1);
      var closeButton = wrapper.find(_index.StyledCloseIcon).first();
      expect(closeButton).toExist(); // verify the toast is cleared

      closeButton.simulate('click');
      jest.runAllTimers(); // verify the toast is removed from the list

      expect(toasterInstance.state.toasts.length).toEqual(0); // verify the onClose toast handler is called

      expect(onClose).toHaveBeenCalled(); // verify no toasts are rendered

      wrapper.update();
      expect(wrapper.find(_index.Toast).length).toEqual(0);
    });
  });
});

==> baseui-5.10.0.tgz: package/toast/__tests__/toaster.test.js <==
"use strict";

var _react = _interopRequireDefault(require("react"));

var _reactDom = _interopRequireDefault(require("react-dom"));

var _enzyme = require("enzyme");

var _index = require("../index.js");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; var ownKeys = Object.keys(source); if (typeof Object.getOwnPropertySymbols === 'function') { ownKeys = ownKeys.concat(Object.getOwnPropertySymbols(source).filter(function (sym) { return Object.getOwnPropertyDescriptor(source, sym).enumerable; })); } ownKeys.forEach(function (key) { _defineProperty(target, key, source[key]); }); } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

// Mock React 16 portals
var originalCreatePortal = _reactDom.default.createPortal;
jest.useFakeTimers();
describe('toaster', function () {
  var wrapper;
  beforeAll(function () {
    // $FlowFixMe
    _reactDom.default.createPortal = jest.fn(function (children) {
      return _react.default.createElement("div", {
        "is-portal": "true",
        key: "portal"
      }, children);
    });
  });
  afterEach(function () {
    _reactDom.default.createPortal.mockClear();

    wrapper && wrapper.unmount();
  });
  afterAll(function () {
    // $FlowFixMe
    _reactDom.default.createPortal = originalCreatePortal;
  });
  test('ToasterContainer', function () {
    wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.ToasterContainer, null));
    var renderedToaster = wrapper.find(_index.ToasterContainer).first();
    expect(renderedToaster.instance().state.isMounted).toBe(true);
    expect(renderedToaster.instance().state.toasts.length).toEqual(0);
    expect(wrapper.find(_index.StyledRoot).first()).toExist();
  });
  describe('ToasterContainer props', function () {
    test.each(Object.keys(_index.PLACEMENT).map(function (pl) {
      return [pl];
    }))('%s placement is passed to the Toaster and StyledRoot component', function (placement) {
      var props = {
        placement: placement
      };
      wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.ToasterContainer, props));
      expect(wrapper.find(_index.ToasterContainer).first().props().placement).toEqual(placement);
      expect(wrapper.find(_index.StyledRoot).first().props().$placement).toEqual(placement);
    });
    test('portal is created when usePortal is set to true', function () {
      wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.ToasterContainer, null));
      expect(wrapper.find(_index.ToasterContainer).first().props().usePortal).toBe(true);
      expect(_reactDom.default.createPortal).toHaveBeenCalled();
    });
    test('portal is not created when usePortal is set to false', function () {
      wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.ToasterContainer, {
        usePortal: false
      }));
      expect(wrapper.find(_index.ToasterContainer).first().props().usePortal).toBe(false);
      expect(_reactDom.default.createPortal).not.toHaveBeenCalled();
    });
  });
  describe('toaster overrides', function () {
    test('Inner components override', function () {
      var overrides = {
        Root: jest.fn().mockImplementation(function (_ref) {
          var children = _ref.children;
          return _react.default.createElement("div", null, children);
        }),
        ToastBody: jest.fn().mockImplementation(function (_ref2) {
          var children = _ref2.children;
          return _react.default.createElement("div", null, children);
        }),
        ToastCloseIcon: jest.fn().mockImplementation(function (_ref3) {
          var children = _ref3.children;
          return _react.default.createElement("svg", null, children);
        })
      }; // $FlowFixMe

      wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.ToasterContainer, {
        overrides: overrides
      }));
      var renderedToaster = wrapper.find(_index.ToasterContainer).first();
      _index.toaster.getRef = jest.fn().mockReturnValue(renderedToaster.instance());

      _index.toaster.show('Toast message');

      wrapper.update();
      Object.keys(overrides).forEach(function (name) {
        expect(wrapper.find(overrides[name]).first()).toExist();
      });
    });
    test('Inner components props and styles overrides', function () {
      var overrides = {
        Root: {
          props: {
            'data-attr': 'root'
          },
          style: {
            borderColor: 'skyblue'
          }
        },
        ToastBody: {
          props: {
            'data-attr': 'body'
          },
          style: {
            backgroundColor: 'skyblue'
          }
        },
        ToastCloseIcon: {
          props: {
            'data-attr': 'closeIcon'
          },
          style: {
            color: 'blue'
          }
        }
      };
      var components = {
        Root: _index.StyledRoot,
        ToastBody: _index.StyledBody,
        ToastCloseIcon: _index.StyledCloseIcon
      };
      wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.ToasterContainer, {
        overrides: overrides
      }));
      var renderedToaster = wrapper.find(_index.ToasterContainer).first();
      _index.toaster.getRef = jest.fn().mockReturnValue(renderedToaster.instance());

      _index.toaster.show('Toast message');

      wrapper.update();
      Object.keys(overrides).forEach(function (name) {
        var passedProps = wrapper.find(components[name]).first().props();
        expect(passedProps['data-attr']).toEqual(overrides[name].props['data-attr']);
        expect(passedProps.$style).toEqual(overrides[name].style);
      });
    });
  });
  describe('toaster methods', function () {
    var renderedToaster;
    beforeEach(function () {
      wrapper = (0, _enzyme.mount)(_react.default.createElement(_index.ToasterContainer, null));
      renderedToaster = wrapper.find(_index.ToasterContainer).first();
      _index.toaster.getRef = jest.fn().mockReturnValue(renderedToaster.instance());
    });
    test('toaster[show | update | clear]', function () {
      var toastCounter = 0;
      var toasterInstance = renderedToaster.instance(); // test toast is updated

      function getKey() {
        return "test-toast-".concat(toastCounter++);
      }

      var MockNode1 = jest.fn().mockImplementation(function () {
        return 'Toast 1';
      });
      var MockNode2 = jest.fn().mockImplementation(function () {
        return 'Toast 2';
      });
      var props1 = {
        key: getKey(),
        children: _react.default.createElement(MockNode1, null)
      };
      var props2 = {
        key: getKey(),
        children: _react.default.createElement(MockNode2, null)
      };
      var showSpy = jest.spyOn(toasterInstance, 'show'); // add the first Toast

      var toastKey1 = _index.toaster.show(props1.children, {
        key: props1.key
      });

      jest.runAllTimers();
      expect(showSpy).toHaveBeenCalledTimes(1);
      expect(showSpy).toHaveBeenCalledWith(props1);
      expect(toasterInstance.state.toasts.length).toEqual(1);
      expect(toasterInstance.state.toasts[0]).toMatchObject(props1); // verify that first Toast is rendered

      wrapper.update();
      expect(wrapper.find(_index.Toast).length).toEqual(1);
      expect(wrapper.find(_index.StyledBody).length).toEqual(1);
      expect(wrapper.find(MockNode1).length).toEqual(1); // add the second Toast

      _index.toaster.show(props2.children, {
        key: props2.key
      });

      jest.runAllTimers();
      expect(showSpy).toHaveBeenCalledTimes(2);
      expect(showSpy).toHaveBeenLastCalledWith(props2);
      expect(toasterInstance.state.toasts.length).toEqual(2);
      expect(toasterInstance.state.toasts[1]).toMatchObject(props2); // verify that second Toast is rendered

      wrapper.update();
      expect(wrapper.find(_index.Toast).length).toEqual(2);
      expect(wrapper.find(_index.StyledBody).length).toEqual(2);
      expect(wrapper.find(MockNode2).length).toEqual(1); // test toast is updated

      var updateSpy = jest.spyOn(toasterInstance, 'update');
      var MockNode3 = jest.fn().mockImplementation(function () {
        return 'Toast updated';
      });
      var updatedProps = {
        children: _react.default.createElement(MockNode3, null),
        kind: _index.KIND.positive
      };

      _index.toaster.update(toastKey1, updatedProps);

      jest.runAllTimers();
      expect(updateSpy).toHaveBeenCalled();
      expect(updateSpy).toHaveBeenCalledWith(toastKey1, updatedProps);
      expect(toasterInstance.state.toasts.length).toEqual(2);
      expect(toasterInstance.state.toasts[0]).toMatchObject(_objectSpread({}, props1, updatedProps));
      expect(toasterInstance.state.toasts[1]).toMatchObject(props2); // verify that updated children are rendered

      wrapper.update();
      expect(wrapper.find(_index.Toast).length).toEqual(2);
      expect(wrapper.find(_index.StyledBody).length).toEqual(2);
      expect(wrapper.find(MockNode1).length).toEqual(0);
      expect(wrapper.find(MockNode3).length).toEqual(1); // test toast is cleared

      var clearSpy = jest.spyOn(toasterInstance, 'clear');

      _index.toaster.clear(toastKey1);

      jest.runAllTimers();
      expect(clearSpy).toHaveBeenCalled();
      expect(clearSpy).toHaveBeenCalledWith(toastKey1);
      expect(toasterInstance.state.toasts.length).toEqual(1); // verify that dismissed toast is not rendered

      wrapper.update();
      expect(wrapper.find(_index.Toast).length).toEqual(1);
      expect(wrapper.find(_index.StyledBody).length).toEqual(1);
      expect(wrapper.find(MockNode3).length).toEqual(0);
      expect(wrapper.find(MockNode2).length).toEqual(1);
    });
    test('info, positive, warning, negative methods and clear all', function () {
      var toasterInstance = renderedToaster.instance();
      var counter = 0;
      ['info', 'positive', 'warning', 'negative'].forEach(function (method) {
        var children = "".concat(method, " toast");

        _index.toaster[method](children);

        counter++;
        var toastsLength = toasterInstance.state.toasts.length;
        expect(toastsLength).toEqual(counter);
        expect(toasterInstance.state.toasts[toastsLength - 1]).toMatchObject({
          key: "toast-".concat(counter - 1),
          children: children,
          kind: _index.KIND[method]
        });
      }); // verify all toasts rendered

      jest.runAllTimers();
      wrapper.update();
      expect(wrapper.find(_index.Toast).length).toEqual(4); // verify oldest toasts are rendered last in the tree

      expect(wrapper.find(_index.Toast).last().props()).toMatchObject({
        kind: _index.KIND.info
      }); // verify all toasts are cleared

      var clearSpy = jest.spyOn(toasterInstance, 'clear');

      _index.toaster.clear();

      jest.runAllTimers();
      expect(clearSpy).toHaveBeenCalled();
      expect(clearSpy).toHaveBeenCalledWith(undefined); // verify no toasts are rendered

      wrapper.update();
      expect(wrapper.find(_index.Toast).length).toEqual(0);
    });
    test('onClose toast handler is called', function () {
      var onClose = jest.fn();

      var toastKey = _index.toaster.show('Toast message', {
        onClose: onClose
      }); // verify the toast is rendered


      wrapper.update();
      expect(wrapper.find(_index.Toast).length).toEqual(1); // verify the toast is cleared

      _index.toaster.clear(toastKey);

      jest.runAllTimers(); // verify the onClose toast handler is called

      expect(onClose).toHaveBeenCalled(); // verify no toasts are rendered

      wrapper.update();
      expect(wrapper.find(_index.Toast).length).toEqual(0);
    });
    test('toast is cleared and onClose is called when it is dismissed by a user', function () {
      var toasterInstance = renderedToaster.instance();
      var onClose = jest.fn();

      _index.toaster.show('Toast message', {
        onClose: onClose
      }); // verify the toast is rendered


      wrapper.update();
      expect(wrapper.find(_index.Toast).length).toEqual(1);
      var closeButton = wrapper.find(_index.StyledCloseIcon).first();
      expect(closeButton).toExist(); // verify the toast is cleared

      closeButton.simulate('click');
      jest.runAllTimers(); // verify the toast is removed from the list

      expect(toasterInstance.state.toasts.length).toEqual(0); // verify the onClose toast handler is called

      expect(onClose).toHaveBeenCalled(); // verify no toasts are rendered

      wrapper.update();
      expect(wrapper.find(_index.Toast).length).toEqual(0);
    });
  });
});
